Authors — SxcAPIClient 0.1.0 documentation

# Authors

## Lead

- Derrick Gilland, dgilland@gmail.com, dgilland@github

## Contributors

- Nathan Cahill, nathan@nathancahill.com, nathancahill@github

- Klaus Sevensleeper, k7sleeper@gmail.com, k7sleeper@github

- Bharadwaj Yarlagadda, yarlagaddabharadwaj@gmail.com, bharadwajyarlagadda@github

- Michael James, urbnjamesmi1@github

- Tim Griesser, tgriesser@gmail.com, tgriesser@github

- Shaun Patterson, shaunpatterson@github

- Brian Beck, beck3905@github

- Frank Epperlein, efenka@github

- Joshua Wilson, jwilson8767@github

- Eli Jose, elijose55@github

- Gonzalo Naveira, gonzalonaveira@github

- Wenbo Zhao, zhaowb@gmail.com, zhaowb@github

- Mervyn Lee, mervynlee94@github

- Weineel Lee, weineel@github